package com.mygdx.game;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.ScreenAdapter;
import com.badlogic.gdx.graphics.GL20;
import com.badlogic.gdx.scenes.scene2d.Stage;
import com.badlogic.gdx.scenes.scene2d.ui.Label;
import com.badlogic.gdx.scenes.scene2d.ui.ProgressBar;
import com.badlogic.gdx.scenes.scene2d.ui.Table;
import com.badlogic.gdx.utils.viewport.ExtendViewport;
import com.badlogic.gdx.utils.viewport.Viewport;
import com.mygdx.game.screens.MainMenuScreen;
import com.mygdx.game.ui.UIElementCreator;
import com.mygdx.game.ui.UIStyle;

/**
 * Loads the game data and displays a loading bar.
 */
public class LoadingScreen extends ScreenAdapter {
    private GameAssetManager gameAssetManager = Game.getGameInstance().assetManager;
    private static ProgressBar loadBar = UIElementCreator.createProgressBar();
    private static Label loading = UIElementCreator.createLabel("Lädt ...", UIStyle.Comic);

    private Viewport viewport;
    private Stage stage;
    private Table table;

    /**
     * Constructor. Starts the loading process.
     */
    public LoadingScreen()
    {
        gameAssetManager.loadData();
    }



    /**
     * Called when the application is resized
     *
     * @param width  the width of the application
     * @param height the height of the application
     */
    @Override
    public void resize(int width, int height) {
        viewport.update(width, height);
    }

    /**
     * Called when this screen becomes the current screen for the Game
     * Creates multiple UI Elements and layout them
     */
    @Override
    public void show() {
        viewport = new ExtendViewport(1280, 720);
        stage = new Stage(viewport);
        table = new Table();
        table.setFillParent(true);
        stage.addActor(table);
        table.add(loading).row();
        table.add(loadBar);
    }


    /**
     * Called when the screen should render itself
     * Updates the loading bar. If all assets are loaded the MainMenuScreen will be set.
     * @param delta the time in seconds since the last render.
     */
    @Override
    public void render(float delta) {
        Gdx.gl.glClearColor(1.0f,1.0f,1.0f,1.0f);
        Gdx.gl.glClear(GL20.GL_COLOR_BUFFER_BIT);

        if(gameAssetManager.manager.update())
        {
            Game.getGameInstance().setScreen(new MainMenuScreen());
        }
        else
        {
            loadBar.setValue(gameAssetManager.manager.getProgress());
        }

        stage.act();
        stage.draw();
    }

    /**
     * Called when this screen is no longer the current screen
     */
    @Override
    public void hide() {
        super.hide();
    }

    /**
     * Called when this screen should release all resources
     */
    @Override
    public void dispose() {
        stage.dispose();
    }


}
