package com.mygdx.game.Music;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.audio.Music;
import com.badlogic.gdx.audio.Sound;

/**
 * Takes care of playing the background music and the button sounds. The background music remains when the scene changes.
 */
public class MusicController {

    // Singleton
    private static MusicController instance = new MusicController();
    private static boolean isBackgroundMusicStarted = false;

    // One background music instance for all classes
    private static Music backgroundMusic = Gdx.audio.newMusic(Gdx.files.internal("DetectivesRoutine.mp3"));
    private static Sound buttonSound = Gdx.audio.newSound(Gdx.files.internal("buttonClick.ogg"));

    private static float buttonSoundVolume = 0.2f;

    // private constructor prevents any other class from instantiating
    private MusicController() {}

    public static MusicController getMusicInstance()
    {
        return instance;
    }

    /**
     * Starts the background music with the chosen volume.
     * @param volume music volume from 0.0f to 1.0f
     */
   public static void startMusic(float volume)
   {
       // only have one background music for the complete game
       if(isBackgroundMusicStarted == false)
       {
           backgroundMusic.setVolume(volume);
           backgroundMusic.play();

           backgroundMusic.setLooping(true); // will repeat playback until music.stop() is called
           isBackgroundMusicStarted = true;
       }
   }

    /**
     * Change the volume of the background Music
     * @param volume music volume
     */
   public static void changeMusicVolume(float volume)
   {
       backgroundMusic.setVolume(volume);
   }

    /**
     * Change the volume of button sounds.
     * @param volume button sound volume
     */
   public static void changeButtonSoundVolume(float volume)
   {
       buttonSoundVolume = volume;
   }

    /**
     * Plays a button click sound once
     */
   public static void playButtonSound(){
        buttonSound.play(buttonSoundVolume);
   }

    /**
     * Delivers volume of the background music
     * @return current volume of the background music
     */
   public static float getMusicVolume()
   {
       return backgroundMusic.getVolume();
   }

    /**
     * Delivers volume of the button sounds.
     * @return current volume of the button sounds.
     */
   public static float getButtonSoundVolume()
   {
       return buttonSoundVolume;
   }

}
