package com.mygdx.game.dialogue;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.graphics.Texture;
import com.badlogic.gdx.scenes.scene2d.ui.*;
import com.mygdx.game.ui.UIElementCreator;
import com.mygdx.game.ui.UIStyle;

/**
 * Defines a dialogue box with typing effect.
 */
public class DialogueBox extends Table {

    private String targetText = "";
    private float animationTimer = 0f;
    private float animationTotalTime = 0f;
    private final static float TIME_PER_CHARACTER = 0.05f;
    private STATE state = STATE.IDLE;
    private TextArea dialogueTextArea;
    private static float windowWidth = 400f;
    private static float windowHeight = 150f;
    private static float padding = 15f;

    private final static Texture texture = new Texture(Gdx.files.internal("UI/DialogBox.png"));

    /**
     * Defines animation states.
     * ANIMATING when the letters are printed out at the dialogue box
     * IDLE when there are no more letters to print out
     */
    private enum STATE {
        ANIMATING,
        IDLE,
        ;
    }

    /**
     * Creates a dialogue window with a TextArea
     */
    public DialogueBox() {
        dialogueTextArea = UIElementCreator.createTextArea("\n", UIStyle.Dialogue);
        dialogueTextArea.setDisabled(true);

        Window window = UIElementCreator.createWindow("", UIStyle.Alt);
        window.setSize(windowWidth,windowHeight);
        window.setMovable(false);
        window.add(dialogueTextArea).width(windowWidth).height(windowHeight).expandX().left().top().pad(padding);

        this.add(window);
    }

    /**
     * Triggers the animation and setup the animation timer
     * @param text target text that should be animated
     */
    public void animateText(String text) {
        targetText = text;
        animationTotalTime = text.length()*TIME_PER_CHARACTER;
        state = STATE.ANIMATING;
        animationTimer = 0f;
    }

    /**
     * Shows if the animation is still running or not
     * @return true if the animation is ready, false if it is not ready
     */
    public boolean isFinished() {
        if (state == STATE.IDLE) {
            return true;
        } else {
            return false;
        }
    }

    /**
     * Set dialogue text with a new letter added
     * @param text the old text with one new extra letter
     */
    private void setText(String text) {
        if (!text.contains("\n")) {
            text += "\n";
        }
        this.dialogueTextArea.setText(text);
    }

    /**
     * Trigger setText method
     * Called each frame
     * @param delta the time in seconds since the last render.
     */
    @Override
    public void act(float delta) {
        if (state == STATE.ANIMATING) {
            animationTimer += delta;
            if (animationTimer > animationTotalTime) {
                state = STATE.IDLE;
                Gdx.app.log("Dialogue", "Animation State changed to IDLE");
                animationTimer = animationTotalTime;
            }
            String actuallyDisplayedText = "";
            int charactersToDisplay = (int)((animationTimer /animationTotalTime)*targetText.length());

            for (int i = 0; i < charactersToDisplay; i++) {
                actuallyDisplayedText += targetText.charAt(i);
            }
            if (!actuallyDisplayedText.equals(dialogueTextArea.getText())) {
                setText(actuallyDisplayedText);
            }
        }
    }

}
