package com.mygdx.game.interrogation;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.files.FileHandle;
import com.badlogic.gdx.utils.Json;

/**
 * Reads the dialogue data in the assets - dialogueFiles Folder.
 */
public class ReaderDialogue {

    private static Interrogation dialogueData;

    /**
     * Delivers the content for the interrogation for a specific person
     *
     * @param dataName name of the dialogue file for example caro.json
     * @return interrogation object with all answers and questions
     */
    public static Interrogation getDialogueData(String dataName) {
        loadDialogueData(dataName);
        return dialogueData;
    }

    /**
     * Loads the dialogue data from a json file and rewrites an interrogation object with new data
     *
     * @param dataName name of the dialogue file for example caro.json
     */
    private static void loadDialogueData(String dataName) {
        Json json = new Json();

        String resourcePath = "";

        try {
            // getProperty("os.name") is not allowed to be changed, because os is an important key word
            // os = operating system
            final String operatingSystem = System.getProperty("os.name");

            if (operatingSystem.contains("Windows")) {
                resourcePath = ".\\core\\assets\\dialogueFiles\\" + dataName;
            }
            if (operatingSystem.contains("Mac"))
            {
                resourcePath = "/Users/dinahblust/Studium/Semester 4/Anwendungsprojekt/krimigame/Game/core/assets/dialogueFiles/" + dataName;

            }
            if (operatingSystem.contains("Linux")){
                resourcePath = "./core/assets/dialogueFiles/" + dataName;
            }
        } catch (final Exception e) {
            Gdx.app.log("File", "Error while trying to load resourcePath in loadData method");
        }

        FileHandle fileHandle = new FileHandle(resourcePath);
        dialogueData = json.fromJson(Interrogation.class, fileHandle);
    }
}
