package com.mygdx.game.screens;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.ScreenAdapter;
import com.badlogic.gdx.graphics.Color;
import com.badlogic.gdx.graphics.GL20;
import com.badlogic.gdx.graphics.Texture;
import com.badlogic.gdx.graphics.g2d.BitmapFont;
import com.badlogic.gdx.graphics.g2d.Sprite;
import com.badlogic.gdx.graphics.g2d.SpriteBatch;
import com.badlogic.gdx.graphics.g2d.TextureAtlas;
import com.badlogic.gdx.graphics.g2d.freetype.FreeTypeFontGenerator;
import com.badlogic.gdx.scenes.scene2d.InputEvent;
import com.badlogic.gdx.scenes.scene2d.Stage;
import com.badlogic.gdx.scenes.scene2d.ui.*;
import com.badlogic.gdx.scenes.scene2d.utils.ClickListener;
import com.badlogic.gdx.utils.viewport.ExtendViewport;
import com.badlogic.gdx.utils.viewport.ScreenViewport;
import com.badlogic.gdx.utils.viewport.Viewport;
import com.mygdx.game.Game;
import com.mygdx.game.GameAssetManager;
import com.mygdx.game.ui.UIElementCreator;

import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;

public class BackgroundScreen extends ScreenAdapter {

    private static Image personFileCaroImage, personFileChrisImage, personFileIsabelleImage, personFileJennyImage,
            personFileJuliaImage, personFileJustinImage, personFileLarissaImage, personFileLeonImage, personFileRolandImage,
            personFileTimImage, personFileVanessaImage;

    private static Stage stage; // used to display user-Interface
    private static Viewport viewport; // display different resolutions
    private static Table mainTable;
    private static Table tablePersonFileWindow;
    private static Texture backgroundImage;
    private static Sprite backgroundSprite;
    private static SpriteBatch spriteBatch = new SpriteBatch();
    private static Window window;
    private static Window fileWindow;
    private static Window personFileWindow;
    private static Skin skin;

    private static Label timeLabel;
    private static boolean isStartMenuCreated = false;

    boolean startMenuBoolean = false;
    Table table;
    Table startMenu;
    String time;
    ImageButton jennyFile, caroFile, chrisFile, vanessaFile, isabelleFile, justinFile, leonFile, timFile, larissaFile,
            juliaFile, rolandFile;
    TextButton interrogationButton;

    GameAssetManager assetManager;
    TextureAtlas personPortraitAtlas;


    public BackgroundScreen() {
        // get Images form the atlas
        TextureAtlas personFileAtlas = Game.getGameInstance().assetManager.manager.get(("personFiles.atlas"));
        personPortraitAtlas = Game.getGameInstance().assetManager.manager.get("personPortrait.atlas");

        personFileChrisImage = new Image(personFileAtlas.findRegion("ChristianWagner"));
        personFileJennyImage = new Image(personFileAtlas.findRegion("JenniferGerber"));
        personFileJuliaImage = new Image(personFileAtlas.findRegion("JuliaGerber"));
        personFileJustinImage = new Image(personFileAtlas.findRegion("JustinWolf"));
        personFileLeonImage = new Image(personFileAtlas.findRegion("LeonReger"));
        personFileVanessaImage = new Image(personFileAtlas.findRegion("VanessaSteiner"));
        personFileCaroImage = new Image(personFileAtlas.findRegion("CarolineGerber"));
        personFileIsabelleImage = new Image(personFileAtlas.findRegion("IsabelleMaier"));
        personFileLarissaImage = new Image(personFileAtlas.findRegion("LarissaKoch"));
        personFileRolandImage = new Image(personFileAtlas.findRegion("RolandGerber"));
        personFileTimImage = new Image(personFileAtlas.findRegion("TimFalk"));
    }

    @Override
    public void show() {

        // reset values
        isStartMenuCreated = false;

        skin = new Skin();
        initializeSkinExpee();

        this.stage = new Stage(new ScreenViewport());

        //size of the screen
        viewport = new ExtendViewport(1280, 720);
        stage = new Stage(viewport);

        //create mainTable
        mainTable = new Table(this.skin);
        mainTable.setFillParent(true);

        //background
        mainTable.setBackground("wallpaper");

        //files
        jennyFile = UIElementCreator.createImageButton(personPortraitAtlas.findRegion("JenniferGerber"));
        caroFile = UIElementCreator.createImageButton(personPortraitAtlas.findRegion("CarolineGerber"));
        chrisFile = UIElementCreator.createImageButton(personPortraitAtlas.findRegion("ChristianWagner"));
        vanessaFile = UIElementCreator.createImageButton(personPortraitAtlas.findRegion("VanessaSteiner"));
        isabelleFile = UIElementCreator.createImageButton(personPortraitAtlas.findRegion("IsabelleMaier"));
        justinFile = UIElementCreator.createImageButton(personPortraitAtlas.findRegion("JustinWolf"));
        leonFile = UIElementCreator.createImageButton(personPortraitAtlas.findRegion("LeonReger"));
        timFile = UIElementCreator.createImageButton(personPortraitAtlas.findRegion("TimFalk"));
        larissaFile = UIElementCreator.createImageButton(personPortraitAtlas.findRegion("LarissaKoch"));
        juliaFile = UIElementCreator.createImageButton(personPortraitAtlas.findRegion("JuliaGerber"));
        rolandFile = UIElementCreator.createImageButton(personPortraitAtlas.findRegion("RolandGerber"));

        //BottomBar will be created
        createBottomBar();

        //creates backgroundImage if the screen has a different size than the wallpaper
        stage.addActor(mainTable);
        backgroundImage = new Texture(Gdx.files.internal("ScreenBackgrounds/backgroundPlaceholder.jpg"));
        backgroundSprite = new Sprite(backgroundImage);
        backgroundSprite.setSize(Gdx.graphics.getWidth(), Gdx.graphics.getHeight());

        Gdx.input.setInputProcessor(stage);

    }

    /**
     * Create the Bottombar on the Screen
     */
    public void createBottomBar() {
        this.stage.addActor(mainTable);
        mainTable.defaults().bottom().expandY();
        startMenu = new Table(this.skin);
        final Button startButton = new Button(this.skin, "start");
        //open and close the startMenu at the startButton
        mainTable.add(startButton);
        startButton.addListener(new ClickListener() {
            @Override
            public void clicked(InputEvent event, float x, float y) {
                if (!isStartMenuCreated) {
                    createStartMenu();
                    isStartMenuCreated = true;
                } else {
                    if (startMenu.isVisible()) {
                        startMenu.setVisible(false);
                    } else {
                        startMenu.setVisible(true);
                    }
                }
            }
        });
        table = new Table(this.skin);
        table.background("taskbar");
        mainTable.add(table).growX();
        table = new Table(this.skin);
        table.background("tray");

        //show time
        timeLabel = new Label(getTime(), this.skin, "white");
        table.add(timeLabel).padLeft(10.0F).padRight(10.0F);
        mainTable.add(table);
    }

    /**
     * Close Button to go back to the MainMenu
     */
    public void closeButton() {
        final TextButton closeButton = new TextButton("Beenden", this.skin, "shutdown");
        table.add(closeButton).padLeft(250.0F).padRight(5.0F).padTop(10.0F).padBottom(-30.0F);
        closeButton.addListener(new ClickListener() {
            /**
             * Will change the screen to the MainMenuScreen
             * @param event button is clicked
             * @param x
             * @param y
             */
            @Override
            public void clicked(InputEvent event, float x, float y) {
                Game.getGameInstance().setScreen(new MainMenuScreen());
            }
        });
        startMenu.add(table).bottom().colspan(2);
        this.stage.addActor(startMenu);
    }

    /**
     * Creates the start menu of the Screen
     */
    public void createStartMenu() {
        startMenu.setBackground("start-menu");
        startMenu.setVisible(true);
        startMenu.setWidth(380.0F);
        startMenu.setHeight(480.0F);
        startMenu.setY(32.0F);
        table = new Table();
        table.add(new TextButton("All Programs ", this.skin, "programs")).bottom().expandY();
        startMenu.add(table).growY();
        table = new Table(this.skin);
        table.setBackground("start-menu-right");
        //Button to switch to the ProofScreen
        Button proofButton = new TextButton("Beschlagnahmungen", this.skin, "programs");
        table.add(proofButton).left().padLeft(-15).padRight(-15).row();
        proofButton.addListener(new ClickListener() {
            /**
             * Will change the screen to the MainMenuScreen
             * @param event button is clicked
             * @param x
             * @param y
             */
            @Override
            public void clicked(InputEvent event, float x, float y) {
                Game.getGameInstance().setScreen(new ProofScreen());
            }
        });
        //Button to open the fileWindow
        Button files = new TextButton("Akten", this.skin, "programs");
        table.add(files).left().padLeft(-15).padRight(-15).row();
        files.addListener(new ClickListener() {
            @Override
            public void clicked(InputEvent event, float x, float y) {
                createFileWindow();
                if (!fileWindow.isVisible()) {
                    fileWindow.setVisible(true);
                }
            }
        });
        //Button to switch to the PastMurderScreen
        Button murder = new TextButton("Der Mörder ist: ", this.skin, "programs");
        table.add(murder).left().padLeft(-15).padRight(-15).row();
        murder.addListener(new ClickListener() {
            /**
             * Will change the screen to the MainMenuScreen
             * @param event button is clicked
             * @param x
             * @param y
             */
            @Override
            public void clicked(InputEvent event, float x, float y) {
                Game.getGameInstance().setScreen(new PasteMurderScreen());
            }
        });

        startMenu.add(table).grow();
        startMenu.row();
        table = new Table(this.skin);
        table.setBackground("start-menu-bottom");
        closeButton();


    }

    /**
     *  Methode to get the local time and format it
     */
    public static String getTime() {
        DateTimeFormatter dtf = DateTimeFormatter.ofPattern("HH:mm:ss");
        String currentTime = dtf.format(LocalDateTime.now());
        return currentTime;
    }





    public void createFileWindow() {
        fileWindow = new Window("Akten", skin);
        stage.addActor(fileWindow);
        fileWindow.setVisible(true);
        final Button closeFiles = new Button(skin, "close");
        fileWindow.getTitleTable().add(closeFiles).right().expandX();
        closeFiles.addListener(new ClickListener() {
            @Override
            public void clicked(InputEvent event, float x, float y) {
                fileWindow.setVisible(false);
            }
        });
        fileWindow.row();
        fileWindow.setFillParent(true);
        table = new Table();
        fileWindow.add(table);
        //table.setDebug(true);

        table.add(jennyFile).size(150, 150).padRight(100).padBottom(100);
        Label labelJenny = new Label("Jennifer Gerber", skin);
        jennyFile.addListener(new ClickListener() {
            /**
             * Will change the screen to the MainMenuScreen
             * @param event button is clicked
             * @param x
             * @param y
             */
            @Override
            public void clicked(InputEvent event, float x, float y) {
                createPersonFileWindow("Jennifer Gerber", personFileJennyImage, null);
                if (!fileWindow.isVisible()) {
                    fileWindow.setVisible(true);
                }
            }
        });


        table.add(caroFile).size(150, 150).padRight(100).padBottom(100);
        Label labelCaro = new Label("Caroline Gerber", skin);
        caroFile.addListener(new ClickListener() {
            @Override
            public void clicked(InputEvent event, float x, float y) {
                createPersonFileWindow("Caroline Gerber", personFileCaroImage, "caro.json");
                if (!fileWindow.isVisible()) {
                    fileWindow.setVisible(true);
                }
            }
        });

        table.add(vanessaFile).size(150, 150).padRight(100).padBottom(100);
        Label labelVanessa = new Label("Vanessa Steiner", skin);
        vanessaFile.addListener(new ClickListener() {
            @Override
            public void clicked(InputEvent event, float x, float y) {
                createPersonFileWindow("Vanessa Steiner", personFileVanessaImage, "vanessa.json");
                if (!fileWindow.isVisible()) {
                    fileWindow.setVisible(true);
                }
            }
        });

        table.add(isabelleFile).size(150, 150).padRight(100).padBottom(100);
        Label labelIsabelle = new Label("Isabelle Maier", skin);
        isabelleFile.addListener(new ClickListener() {
            @Override
            public void clicked(InputEvent event, float x, float y) {
                createPersonFileWindow("Isabelle Maier", personFileIsabelleImage, "isabelle.json");
                if (!fileWindow.isVisible()) {
                    fileWindow.setVisible(true);
                }
            }
        });


        table.add(justinFile).size(150, 150).padBottom(100).row();
        Label labelJustin = new Label("Justin Wolf", skin);
        justinFile.addListener(new ClickListener() {
            @Override
            public void clicked(InputEvent event, float x, float y) {
                createPersonFileWindow("Justin Wolf", personFileJustinImage, "justin.json");
                if (!fileWindow.isVisible()) {
                    fileWindow.setVisible(true);
                }
            }
        });

        table.add(labelJenny).left().top().padTop(-100).padLeft(25);
        table.add(labelCaro).left().top().padTop(-100).padLeft(25);
        table.add(labelVanessa).left().top().padTop(-100).padLeft(25);
        table.add(labelIsabelle).left().top().padTop(-100).padLeft(30);
        table.add(labelJustin).left().top().padTop(-100).padLeft(40).row();

        table.add(leonFile).size(150, 150).padLeft(-100).padBottom(100);
        Label labelLeon = new Label("Leon Reger", skin);
        leonFile.addListener(new ClickListener() {
            @Override
            public void clicked(InputEvent event, float x, float y) {
                createPersonFileWindow("Leon Reger", personFileLeonImage, "leon.json");
                if (!fileWindow.isVisible()) {
                    fileWindow.setVisible(true);
                }
            }
        });

        table.add(timFile).size(150, 150).padRight(100).padBottom(100);
        Label labelTim = new Label("Tim Falk", skin);
        timFile.addListener(new ClickListener() {
            @Override
            public void clicked(InputEvent event, float x, float y) {
                createPersonFileWindow("Tim Falk", personFileTimImage, "tim.json");
                if (!fileWindow.isVisible()) {
                    fileWindow.setVisible(true);
                }
            }
        });

        table.add(larissaFile).size(150, 150).padRight(100).padBottom(100);
        Label labelLarissa = new Label("Larissa Koch", skin);
        larissaFile.addListener(new ClickListener() {
            @Override
            public void clicked(InputEvent event, float x, float y) {
                createPersonFileWindow("Larissa Koch", personFileLarissaImage, "larissa.json");
                if (!fileWindow.isVisible()) {
                    fileWindow.setVisible(true);
                }
            }
        });

        table.add(juliaFile).size(150, 150).padRight(100).padBottom(100);
        Label labelJulia = new Label("Julia Gerber", skin);
        juliaFile.addListener(new ClickListener() {
            @Override
            public void clicked(InputEvent event, float x, float y) {
                createPersonFileWindow("Julia Gerber", personFileJuliaImage, "julia.json");
                if (!fileWindow.isVisible()) {
                    fileWindow.setVisible(true);
                }
            }
        });

        table.add(rolandFile).size(150, 150).padBottom(100).row();
        Label labelRoland = new Label("Roland Gerber", skin);
        rolandFile.addListener(new ClickListener() {
            @Override
            public void clicked(InputEvent event, float x, float y) {
                createPersonFileWindow("Roland Gerber", personFileRolandImage, "roland.json");
                if (!fileWindow.isVisible()) {
                    fileWindow.setVisible(true);
                }
            }
        });

        table.add(labelLeon).left().top().padTop(-100).padLeft(40).padBottom(100);
        table.add(labelTim).left().top().padTop(-100).padLeft(45);
        table.add(labelLarissa).left().top().padTop(-100).padLeft(35);
        table.add(labelJulia).left().top().padTop(-100).padLeft(35);
        table.add(labelRoland).left().top().padTop(-100).padLeft(30).row();

        table.add(chrisFile).size(150, 150).padLeft(-100).row();
        Label labelChris = new Label("Christian Wagner", skin);
        chrisFile.addListener(new ClickListener() {
            @Override
            public void clicked(InputEvent event, float x, float y) {
                createPersonFileWindow("Christian Wagner", personFileChrisImage, "chris.json");
                if (!fileWindow.isVisible()) {
                    fileWindow.setVisible(true);
                }
            }
        });
        table.add(labelChris).left().top().padLeft(20);

    }


    /**
     * create Window to show the different Files of the Persons
     */
    public void createPersonFileWindow(String person, Image peronFileImage, String dialogFile) {
        personFileWindow = new Window("Akte von " + person, this.skin);
        stage.addActor(personFileWindow);
        personFileWindow.setVisible(true);
        final Button closeFiles = new Button(this.skin, "close");
        personFileWindow.getTitleTable().add(closeFiles).right().expandX();
        closeFiles.addListener(new ClickListener() {
            @Override
            public void clicked(InputEvent event, float x, float y) {
                personFileWindow.setVisible(false);
            }
        });
        personFileWindow.row();
        tablePersonFileWindow = new Table();
        personFileWindow.add(tablePersonFileWindow).grow();
        personFileWindow.setFillParent(true);
        tablePersonFileWindow.add(peronFileImage).size(1000, 700).bottom().padTop(15.0F);
        if (!person.equals("Jennifer Gerber")) {
            interrogationButton = new TextButton("Befragung von " + person + " starten", this.skin);
            tablePersonFileWindow.add(interrogationButton);
            interrogationButton.addListener(new ClickListener() {
                @Override
                public void clicked(InputEvent event, float x, float y) {
                    Game.getGameInstance().setScreen(new InterrogationScreen(dialogFile, person));
                }
            });
        }
    }


    /**
     * Called when the screen should render itself
     *
     * @param delta the time in seconds since the last render.
     */
    @Override
    public void render(float delta) {

        // clear screen
        Gdx.gl.glClearColor(1f, 1f, 1f, 1);
        Gdx.gl.glClear(GL20.GL_COLOR_BUFFER_BIT);


        stage.act();
        spriteBatch.begin();
        backgroundSprite.draw(spriteBatch);
        timeLabel.setText(getTime());
        spriteBatch.end();

        stage.draw();
    }


    private static void initializeSkinExpee() {
        FreeTypeFontGenerator generator = new FreeTypeFontGenerator(Gdx.files.internal("Roboto-Black.ttf"));
        FreeTypeFontGenerator.FreeTypeFontParameter parameter = new FreeTypeFontGenerator.FreeTypeFontParameter();
        parameter.size = 12;
        parameter.color = Color.BLACK;
        BitmapFont font = generator.generateFont(parameter);
        skin.add("Roboto-Black", font);
        skin.addRegions(new TextureAtlas("skinExpeePro/skinExpeePro.atlas"));
        skin.load(Gdx.files.internal("skinExpeePro/skinExpeePro.json"));
    }

    @Override
    public void dispose() {
        stage.dispose();
    }

}
