package com.mygdx.game.screens;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.ScreenAdapter;
import com.badlogic.gdx.graphics.GL20;
import com.badlogic.gdx.graphics.Texture;
import com.badlogic.gdx.graphics.g2d.Sprite;
import com.badlogic.gdx.graphics.g2d.SpriteBatch;
import com.badlogic.gdx.scenes.scene2d.InputEvent;
import com.badlogic.gdx.scenes.scene2d.Stage;
import com.badlogic.gdx.scenes.scene2d.ui.Button;
import com.badlogic.gdx.scenes.scene2d.ui.Label;
import com.badlogic.gdx.scenes.scene2d.ui.Table;
import com.badlogic.gdx.scenes.scene2d.ui.Window;
import com.badlogic.gdx.scenes.scene2d.utils.ClickListener;
import com.badlogic.gdx.utils.viewport.ExtendViewport;
import com.badlogic.gdx.utils.viewport.Viewport;
import com.mygdx.game.Game;
import com.mygdx.game.Music.MusicController;
import com.mygdx.game.ui.UIElementCreator;
import com.mygdx.game.ui.UIStyle;

public class DescriptionScreen extends ScreenAdapter {


    private static Stage stage; // used to display user-Interface
    private static Viewport viewport; // display different resolutions
    private static Table mainTable;
    private static Texture backgroundImage;
    private static Sprite backgroundSprite;
    private static SpriteBatch spriteBatch = new SpriteBatch();
    private static Window window;


    @Override
    public void show() {

        createScreen();

        Button startButton = UIElementCreator.createTextButton("Weiter", UIStyle.Comic);
        startButton.addListener(new ClickListener()
        {
            /**
             * Will change the screen to the MainMenuScreen
             * @param event button is clicked
             * @param x
             * @param y
             */
            @Override
            public void clicked(InputEvent event, float x, float y) {
                MusicController.playButtonSound();
                backgroundImage = new Texture(Gdx.files.internal("GameDescription/Persona.jpg"));
                backgroundSprite = new Sprite(backgroundImage);
                backgroundSprite.setSize(Gdx.graphics.getWidth(), Gdx.graphics.getHeight());

                resetStartButton(startButton);
            }
        });

        mainTable.pad(10);
        mainTable.add(startButton).top().right().pad(10f).expand();
        Gdx.input.setInputProcessor(stage);
    }

    private static void resetStartButton(Button startButton)
    {
        startButton.reset();
        Label startGame = UIElementCreator.createLabel("Starten",UIStyle.Comic);
        startButton.add(startGame);

        startButton.addListener(new ClickListener()
        {
            /**
             * Will change the screen to the WinScreen
             * @param event button is clicked
             * @param x
             * @param y
             */
            @Override
            public void clicked(InputEvent event, float x, float y) {
                MusicController.playButtonSound();
                Game.getGameInstance().setScreen(new BackgroundScreen());
            }
        });


    }


    private static void createScreen() {
        viewport = new ExtendViewport(1280, 720);
        stage = new Stage(viewport);
        mainTable = new Table();
        mainTable.setFillParent(true);
        stage.addActor(mainTable);
        backgroundImage = new Texture(Gdx.files.internal("Gamedescription/Versuch1.jpg"));
        backgroundSprite = new Sprite(backgroundImage);
        backgroundSprite.setSize(Gdx.graphics.getWidth(), Gdx.graphics.getHeight());

        mainTable.add(window);
    }

    /**
     * Called when the screen should render itself
     *
     * @param delta the time in seconds since the last render.
     */
    @Override
    public void render(float delta) {

        // clear screen
        Gdx.gl.glClearColor(1f, 1f, 1f, 1);
        Gdx.gl.glClear(GL20.GL_COLOR_BUFFER_BIT);

        stage.act();
        spriteBatch.begin();
        backgroundSprite.draw(spriteBatch);
        spriteBatch.end();

        stage.draw();
    }
}
