package com.mygdx.game.screens;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.ScreenAdapter;
import com.badlogic.gdx.assets.AssetManager;
import com.badlogic.gdx.graphics.GL20;
import com.badlogic.gdx.graphics.Texture;
import com.badlogic.gdx.graphics.g2d.Sprite;
import com.badlogic.gdx.graphics.g2d.SpriteBatch;
import com.badlogic.gdx.graphics.g2d.TextureAtlas;
import com.badlogic.gdx.scenes.scene2d.InputEvent;
import com.badlogic.gdx.scenes.scene2d.Stage;
import com.badlogic.gdx.scenes.scene2d.ui.*;
import com.badlogic.gdx.scenes.scene2d.utils.ClickListener;
import com.badlogic.gdx.utils.viewport.ExtendViewport;
import com.badlogic.gdx.utils.viewport.Viewport;
import com.mygdx.game.Game;
import com.mygdx.game.GameAssetManager;
import com.mygdx.game.Music.MusicController;
import com.mygdx.game.ui.UIElementCreator;
import com.mygdx.game.ui.UIStyle;

/**
 * Shows the main menu with interaction possibilities like options, credits, exit and to start the game.
 */
public class MainMenuScreen extends ScreenAdapter {

    private static Stage stage; // used to display user-Interface
    private static Viewport viewport; // display different resolutions
    private static Table mainTable;

    private static Texture backgroundTexture;
    private static Sprite backgroundSprite;
    private static SpriteBatch spriteBatch = new SpriteBatch();

    /**
     * Called when this screen becomes the current screen for the Game
     * Creates multiple UI Elements and layout them
     */
    @Override
    public void show() {

        createScreen();
        MusicController.startMusic(0.5f);

        // create and layout UI elements
        Label label = UIElementCreator.createLabel("Auf der Spur", UIStyle.Title);

        mainTable.add(label).fillX().padBottom(10);

        mainTable.row();

        addTextButton("Spiel starten").addListener(new ClickListener() {
            /**
             * Change the screen to InterrogationScreen
             * @param event button is clicked
             * @param x
             * @param y
             */
            @Override
            public void clicked(InputEvent event, float x, float y) {
               MusicController.playButtonSound();

//              Game.getGameInstance().setScreen(new InterrogationScreen("justin.json", "Justin Wolf"));
               Game.getGameInstance().setScreen(new DescriptionScreen());


            }
        });


        addTextButton("Optionen").addListener(new ClickListener() {
            /**
             * Change screen to OptionScreen
             * @param event button clicked
             * @param x
             * @param y
             */
            @Override
            public void clicked(InputEvent event, float x, float y) {
                MusicController.playButtonSound();
                Game.getGameInstance().setScreen(new OptionScreen());

            }
        });



        addTextButton("Credits").addListener(new ClickListener() {
            /**
             * Change screen to CreditsScreen
             * @param event button clicked
             * @param x
             * @param y
             */
            @Override
            public void clicked(InputEvent event, float x, float y) {
                MusicController.playButtonSound();
                Game.getGameInstance().setScreen(new CreditScreen());
            }
        });


        addTextButton("Beenden").addListener(new ClickListener() {
            /**
             * End the game
             * @param event button clicked
             * @param x
             * @param y
             */
            @Override
            public void clicked(InputEvent event, float x, float y) {
               MusicController.playButtonSound();
                Gdx.app.exit();
            }
        });

        Gdx.input.setInputProcessor(stage);
    }

    /**
     * Adds TextButtons to the table with the same paddings
     *
     * @param name name of the button that will be displayed in UI
     * @return one TextButton for the menu
     */
    private TextButton addTextButton(String name) {
        TextButton button = UIElementCreator.createTextButton(name, UIStyle.Comic);
        mainTable.add(button).fillX().padBottom(10);
        mainTable.row();
        return button;
    }

    /**
     * Called when the screen should render itself
     *
     * @param delta the time in seconds since the last render.
     */
    @Override
    public void render(float delta) {

        // clear screen
        Gdx.gl.glClearColor(1f, 1f, 1f, 1);
        Gdx.gl.glClear(GL20.GL_COLOR_BUFFER_BIT);

        stage.act();

        spriteBatch.begin();
        backgroundSprite.draw(spriteBatch);
        spriteBatch.end();

        stage.draw();
    }

    /**
     * Called when the application is resized
     *
     * @param width  the width of the application
     * @param height the height of the application
     */
    @Override
    public void resize(int width, int height) {
        viewport.update(width, height);
    }

    /**
     * Called when this creen should release all resources
     */
    @Override
    public void dispose() {
        stage.dispose();

    }

    /**
     * Called when this screen is no longer the current screen
     */
    @Override
    public void hide() {
        super.hide();
    }

    /**
     * Creates elements for the screen like stage, viewport and table
     */
    private static void createScreen() {
        viewport = new ExtendViewport(1280, 720);
        stage = new Stage(viewport);
        mainTable = new Table();
        mainTable.setFillParent(true);
        stage.addActor(mainTable);

        backgroundTexture = new Texture(Gdx.files.internal("ScreenBackgrounds/policeRoom.jpg"));
        backgroundSprite = new Sprite(backgroundTexture);
        backgroundSprite.setSize(Gdx.graphics.getWidth(), Gdx.graphics.getHeight());
    }

}