package com.mygdx.game.screens;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.ScreenAdapter;
import com.badlogic.gdx.graphics.GL20;
import com.badlogic.gdx.graphics.Texture;
import com.badlogic.gdx.graphics.g2d.Sprite;
import com.badlogic.gdx.graphics.g2d.SpriteBatch;
import com.badlogic.gdx.scenes.scene2d.InputEvent;
import com.badlogic.gdx.scenes.scene2d.Stage;
import com.badlogic.gdx.scenes.scene2d.ui.*;
import com.badlogic.gdx.scenes.scene2d.utils.ClickListener;
import com.badlogic.gdx.utils.viewport.ExtendViewport;
import com.badlogic.gdx.utils.viewport.Viewport;
import com.mygdx.game.Game;
import com.mygdx.game.Music.MusicController;
import com.mygdx.game.ui.UIElementCreator;
import com.mygdx.game.ui.UIStyle;

public class PasteMurderScreen extends ScreenAdapter {


    private static Stage stage; // used to display user-Interface
    private static Viewport viewport; // display different resolutions
    private static Table mainTable;

    private static Texture backgroundTexture;
    private static Sprite backgroundSprite;
    private static SpriteBatch spriteBatch = new SpriteBatch();

    private String [] names = {"Wähle den Mörder aus:", "Caroline Gerber", "Justin Wolf", "Chris Wagner", "Isabelle Maier", "Larissa Koch", "Leon Reger", "Tim Falk", "Vanessa Steiner", "Roland Gerber", "Julia Gerber"};
    private SelectBox murderSelectBox = UIElementCreator.createSelectBox(names, UIStyle.Comic);


    @Override
    public void show() {
        // create Layout and  UI elements
        createScreen();
        Button backButton = UIElementCreator.createTextButton("Zurück", UIStyle.Comic);
        backButton.addListener(new ClickListener()
        {
            /**
             * Will change the screen to the MainMenuScreen
             * @param event button is clicked
             * @param x
             * @param y
             */
            @Override
            public void clicked(InputEvent event, float x, float y) {
                MusicController.playButtonSound();
                Game.getGameInstance().setScreen(new BackgroundScreen());

            }
        });

        Button pasteButton = UIElementCreator.createTextButton("Fertig", UIStyle.Comic);
        pasteButton.addListener(new ClickListener()
        {
            /**
             * Will change the screen to the WinScreen if the player choose the right name, or LooseScreen otherwise
             * @param event button is clicked
             * @param x
             * @param y
             */
            @Override
            public void clicked(InputEvent event, float x, float y) {
                MusicController.playButtonSound();

                String selectedName = murderSelectBox.getSelected().toString();
                if (selectedName.equals("Caroline Gerber"))
                {
                    Game.getGameInstance().setScreen(new WinScreen());
                }
                else
                {
                    backgroundTexture = new Texture(Gdx.files.internal("WinLoseScreen/LoseScreen.jpg"));
                    backgroundSprite = new Sprite(backgroundTexture);
                    backgroundSprite.setSize(Gdx.graphics.getWidth(), Gdx.graphics.getHeight());

                    looseGame(backButton,pasteButton,murderSelectBox);
                }
            }
        });

        // Layout UI elements
        VerticalGroup verticalGroup = new VerticalGroup();

        verticalGroup.addActor(murderSelectBox);
        verticalGroup.addActor(pasteButton);
        verticalGroup.space(10f);

        mainTable.add(backButton).top().right().pad(10f).expandX().row();
        mainTable.add(verticalGroup).center().expand();

        Gdx.input.setInputProcessor(stage);
    }

    private static void looseGame(Button backButton, Button pasteButton, SelectBox murderSelectBox)
    {
        murderSelectBox.setVisible(false);
        pasteButton.setVisible(false);

        backButton.reset();
        Label endGame = UIElementCreator.createLabel("Beenden",UIStyle.Comic);
        backButton.add(endGame);
        backButton.addListener(new ClickListener()
        {
            /**
             * Will change the screen to the MainMenuScreen
             * @param event button is clicked
             * @param x
             * @param y
             */
            @Override
            public void clicked(InputEvent event, float x, float y) {
                MusicController.playButtonSound();
                Game.getGameInstance().setScreen(new MainMenuScreen());
            }
        });
    }


    /**
     * Called when the screen should render itself
     *
     * @param delta the time in seconds since the last render.
     */
    @Override
    public void render(float delta) {

        // clear screen
        Gdx.gl.glClearColor(1f, 1f, 1f, 1);
        Gdx.gl.glClear(GL20.GL_COLOR_BUFFER_BIT);

        stage.act();

        spriteBatch.begin();
        backgroundSprite.draw(spriteBatch);
        spriteBatch.end();

        stage.draw();
    }

    /**
     * Called when the application is resized
     *
     * @param width  the width of the application
     * @param height the height of the application
     */
    @Override
    public void resize(int width, int height) {
        viewport.update(width, height);
    }

    /**
     * Called when this creen should release all resources
     */

    @Override
    public void hide() {
        super.hide();
    }

    @Override
    public void dispose() {
        stage.dispose();

    }

    /**
     * Called when this screen is no longer the current screen
     */

    /**
     * Creates elements for the screen like stage, viewport and table
     */
    private static void createScreen() {
        viewport = new ExtendViewport(1280, 720);
        stage = new Stage(viewport);
        mainTable = new Table();
        mainTable.setFillParent(true);
        stage.addActor(mainTable);

        backgroundTexture = new Texture(Gdx.files.internal("ScreenBackgrounds/policeRoom.jpg"));
        backgroundSprite = new Sprite(backgroundTexture);
        backgroundSprite.setSize(Gdx.graphics.getWidth(), Gdx.graphics.getHeight());
    }

}
