package com.mygdx.game.screens;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.ScreenAdapter;
import com.badlogic.gdx.graphics.GL20;
import com.badlogic.gdx.graphics.Texture;
import com.badlogic.gdx.graphics.g2d.Sprite;
import com.badlogic.gdx.graphics.g2d.SpriteBatch;
import com.badlogic.gdx.graphics.g2d.TextureAtlas;
import com.badlogic.gdx.scenes.scene2d.InputEvent;
import com.badlogic.gdx.scenes.scene2d.Stage;
import com.badlogic.gdx.scenes.scene2d.ui.*;
import com.badlogic.gdx.scenes.scene2d.utils.ClickListener;
import com.badlogic.gdx.utils.viewport.ExtendViewport;
import com.badlogic.gdx.utils.viewport.ScreenViewport;
import com.badlogic.gdx.utils.viewport.Viewport;
import com.mygdx.game.Game;

import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;


public class ProofScreen extends ScreenAdapter {

    //WhatsAppImages
    private static Image whatsAppImageCaro, whatsAppImageChris, whatsAppImageIsabelle, whatsAppImageJustin, whatsAppImageMama, whatsAppImageVanessa;

    //DiaryImages
    private static Image diaryImageCover, diaryImageOne, diaryImageTwo, diaryImageThree, diaryImageFour, diaryImageFive,
        diaryImageSix, diaryImageSeven;

    // protocolImage and letterImage
    private static final Texture protocolTexture = new Texture(Gdx.files.internal("protocol/Protokoll_des_Abends.jpg"));
    private static final Image protocolImage = new Image(protocolTexture);
    private static final Texture letterTexture = new Texture(Gdx.files.internal("letters/Liebesbrief.jpg"));
    private static final Image letterImage = new Image(letterTexture);


    //Pictures of the night
    private static Image pictureOneImage, pictureTwoImage, pictureThreeImage, pictureFourImage, pictureFiveImage;

    private static Stage stage; // used to display user-Interface
    private static Table mainTable;
    private static Table rightTable;
    private static Table table;
    private static Table startMenu;
    private static Sprite backgroundSprite;
    private static final SpriteBatch spriteBatch = new SpriteBatch();
    private static Window window;
    private Skin skin;

    private Button backButton;
    private static Label timeLabel;


    private int counter = 1;


    public ProofScreen()
    {

        // get images from atlas
        TextureAtlas diaryAtlas = Game.getGameInstance().assetManager.manager.get("diary.atlas");
        TextureAtlas whatsAppAtlas = Game.getGameInstance().assetManager.manager.get("whatsApp.atlas");
        TextureAtlas hdmPictures = Game.getGameInstance().assetManager.manager.get("picturesHDM.atlas");

        // assign diary images
        diaryImageCover = new Image(diaryAtlas.findRegion("Cover"));
        diaryImageOne = new Image(diaryAtlas.findRegion("Diary01"));
        diaryImageTwo = new Image(diaryAtlas.findRegion("Diary02"));
        diaryImageThree = new Image(diaryAtlas.findRegion("Diary03"));
        diaryImageFour = new Image(diaryAtlas.findRegion("Diary04"));
        diaryImageFive = new Image(diaryAtlas.findRegion("Diary05"));
        diaryImageSix = new Image(diaryAtlas.findRegion("Diary06"));
        diaryImageSeven = new Image(diaryAtlas.findRegion("Diary07"));

        // assign whatsapp images
        whatsAppImageCaro = new Image(whatsAppAtlas.findRegion("CaroWA"));
        whatsAppImageChris = new Image(whatsAppAtlas.findRegion("ChrisWA"));
        whatsAppImageIsabelle = new Image(whatsAppAtlas.findRegion("IsabelleWA"));
        whatsAppImageJustin = new Image(whatsAppAtlas.findRegion("JustinWA"));
        whatsAppImageMama = new Image(whatsAppAtlas.findRegion("MamaWA"));
        whatsAppImageVanessa = new Image(whatsAppAtlas.findRegion("VanessaWA"));

        // assign hdm pictures
        pictureOneImage = new Image(hdmPictures.findRegion("Death"));
        pictureTwoImage = new Image(hdmPictures.findRegion("Stairs"));
        pictureThreeImage= new Image(hdmPictures.findRegion("StairsOther"));
        pictureFourImage= new Image(hdmPictures.findRegion("Up"));
        pictureFiveImage= new Image(hdmPictures.findRegion("UpOther"));
    }


    @Override
    public void show() {

        // reset values

        this.skin = new Skin(Gdx.files.internal("skinExpee/expee-ui.json"));
        stage = new Stage(new ScreenViewport());
        //size of the screen
        // display different resolutions
        Viewport viewport = new ExtendViewport(1280, 720);
        stage = new Stage(viewport);

        //create mainTable
        mainTable = new Table(this.skin);
        mainTable.setFillParent(true);


        //Button for switching to the MainMenuScreen

        backButton = new Button(this.skin, "close");
        backButton.addListener(new ClickListener() {
            @Override
            public void clicked(InputEvent event, float x, float y) {
                Game.getGameInstance().setScreen(new BackgroundScreen());
            }
        });


        createBottomBar();
        createBackground();

        //creates backgroundImage if the screen has a different size than the background of the createBackground methode
        stage.addActor(mainTable);
        Texture backgroundImage = new Texture(Gdx.files.internal("ScreenBackgrounds/backgroundPlaceholder.jpg"));
        backgroundSprite = new Sprite(backgroundImage);
        backgroundSprite.setSize(Gdx.graphics.getWidth(), Gdx.graphics.getHeight());

        Gdx.input.setInputProcessor(stage);
    }


    /**
     * Create the BottomBar on the Screen
     */
    public void createBottomBar() {
        stage.addActor(mainTable);
        mainTable.defaults().bottom().expandY();
        startMenu = new Table(this.skin);

        table = new Table(this.skin);
        table.background("taskbar");
        mainTable.add(table).growX();
        table = new Table(this.skin);
        table.background("tray");

        //show time
        timeLabel = new Label(getTime(), this.skin, "white");
        table.add(timeLabel).padLeft(10.0F).padRight(10.0F);
        mainTable.add(table);
    }

    /**
     * create the BackgroundScreen
     */
    public void createBackground() {
        startMenu.setBackground("start-menu");
        startMenu.setWidth(1280.0F);
        startMenu.setHeight(720.0F);
        startMenu.setY(32.0F);
        Table leftTable = new Table();

        //Button to show the WhatsAppImages
        Button imageButtonWhatsApp = new TextButton("Whatsapp Verlauf", this.skin, "programs");
        imageButtonWhatsApp.addListener(new ClickListener() {
            @Override
            public void clicked(InputEvent event, float x, float y) {
                showWhatsAppImages(whatsAppImageCaro);
            }
        });
        leftTable.add(imageButtonWhatsApp).row();

        //Button to show the DiaryImages
        Button imageButtonDiary = new TextButton("Tagebucheintrag", this.skin, "programs");
        imageButtonDiary.addListener(new ClickListener() {
            @Override
            public void clicked(InputEvent event, float x, float y) {
                showDiaryImage(diaryImageCover);
            }
        });
        leftTable.add(imageButtonDiary).row();

        //Button to show the letter
        Button imageButtonLetter = new TextButton("Liebesbrief", this.skin, "programs");
        imageButtonLetter.addListener(new ClickListener() {
            @Override
            public void clicked(InputEvent event, float x, float y) {
                rightTable.clear();
                rightTable.add(letterImage).center().center().pad(10f).size(450, 600);
            }
        });
        leftTable.add(imageButtonLetter).row();

        //Button to show the protocol
        Button imageButtonProtocol = new TextButton("Protokoll des Abends", this.skin, "programs");
        imageButtonProtocol.addListener(new ClickListener() {
            @Override
            public void clicked(InputEvent event, float x, float y) {
                rightTable.clear();
                rightTable.add(protocolImage).center().center().pad(10f).size(450, 600);
            }
        });
        leftTable.add(imageButtonProtocol).row();


        //button to show pictures of the night
        Button imageButtonPicturesNight = new TextButton("Bilder des Geschehens", this.skin, "programs");
        imageButtonPicturesNight.addListener(new ClickListener() {
            @Override
            public void clicked(InputEvent event, float x, float y) {
                showPicturesOfTheNight(pictureOneImage);
            }
        });
        leftTable.add(imageButtonPicturesNight).row();

        leftTable.add(backButton);
        startMenu.add(leftTable).growY();

        //rightTable:
        rightTable = new Table(this.skin);
        rightTable.setBackground("start-menu-right");
        startMenu.add(rightTable).grow();
        startMenu.row();
        table = new Table(this.skin);
        startMenu.add(table).bottom().colspan(20);
        stage.addActor(startMenu);

    }

    /**
     * To switch between the picturesOfTheNight
     * @param imageName the image that should be displayed
     */
    public void showPicturesOfTheNight(Image imageName) {
        //RightButton Pictures
        Button buttonRightPictures = new TextButton(">", this.skin);
        buttonRightPictures.addListener(new ClickListener() {
            @Override
            public void clicked(InputEvent event, float x, float y) {
                for (int i = 0; i < 6; i++) {
                    if (counter < 5) {
                        counter++;
                    } else counter = 1;
                }
                switchPicturesNight();
            }
        });

        //LeftButton Pictures
        Button buttonLeftPictures = new TextButton("<", this.skin);
        buttonLeftPictures.addListener(new ClickListener() {
            @Override
            public void clicked(InputEvent event, float x, float y) {
                for (int i = 0; i < 6; i++) {
                    if (counter >= 2) {
                        counter--;
                    } else counter = 5;
                }
                switchPicturesNight();
            }
        });

        rightTable.clear();
        rightTable.setBackground("start-menu-right");
        rightTable.add(buttonLeftPictures).left().padLeft(10f);
        rightTable.add(imageName).padLeft(20.0F).padRight(5.0F).size(300, 600);
        rightTable.add(buttonRightPictures).right().padRight(10f);
    }

    /**
     *   The switch function to the showPicturesOfTheNight function, so that the correct image is displayed
     */
    private void switchPicturesNight() {
        switch (counter) {
            case 1:
                showPicturesOfTheNight(pictureOneImage);
                break;
            case 2:
                showPicturesOfTheNight(pictureTwoImage);
                break;
            case 3:
                showPicturesOfTheNight(pictureThreeImage);
                break;
            case 4:
                showPicturesOfTheNight(pictureFourImage);
                break;
            case 5:
                showPicturesOfTheNight(pictureFiveImage);
                break;
        }

    }

    /**
     * To switch between the whatsAppImages
     * @param imageName the image that should be displayed
     */
    public void showWhatsAppImages(Image imageName) {

        //RightButtonWhatsApp
        Button buttonRightWhatsApp = new TextButton(">", this.skin);
        buttonRightWhatsApp.addListener(new ClickListener()
        {
            @Override
            public void clicked(InputEvent event, float x, float y) {
                for (int i = 0; i < 7; i++) {
                    if(counter <6) {
                        counter++;
                    }else counter = 1;
                }
                switchWhatsAppImage();
            }
        });

        //LeftButton WhatsApp
        Button buttonLeftWhatsApp = new TextButton("<", this.skin);
        buttonLeftWhatsApp.addListener(new ClickListener()
        {
            @Override
            public void clicked(InputEvent event, float x, float y) {
                for (int i = 0; i < 7; i++) {
                    if(counter >=2) {
                        counter--;
                    }else counter = 6;
                }
                switchWhatsAppImage();
            }
        });

        rightTable.clear();
        rightTable.setBackground("start-menu-right");
        rightTable.add(buttonLeftWhatsApp).left().padLeft(10f);
        rightTable.add(imageName).padLeft(20.0F).padRight(5.0F).size(300, 600);
        rightTable.add(buttonRightWhatsApp).right().padRight(10f);
    }



    /**
     *   The switch function to the showWhatsAppImages function, so that the correct image is displayed
     */
    private void switchWhatsAppImage() {
        switch(counter) {
            case 1:
                showWhatsAppImages(whatsAppImageCaro);
                break;
            case 2:
                showWhatsAppImages(whatsAppImageChris);
                break;
            case 3:
                showWhatsAppImages(whatsAppImageIsabelle);
                break;
            case 4:
                showWhatsAppImages(whatsAppImageJustin);
                break;
            case 5:
                showWhatsAppImages(whatsAppImageMama);
                break;
            case 6:
                showWhatsAppImages(whatsAppImageVanessa);
                break;
        }

    }

    /**
     * To switch between the diaryImages
     * @param imageName the image that should be displayed
     */
    public void showDiaryImage(Image imageName) {

        //RightButton Diary
        Button buttonRightDiary = new TextButton(">", this.skin);
        buttonRightDiary.addListener(new ClickListener()
        {
            @Override
            public void clicked(InputEvent event, float x, float y) {
                for (int i = 0; i < 9; i++) {
                    if(counter <8) {
                        counter++;
                    }else counter = 1;
                }
                SwitchDiaryImage();
            }
        });

        //LeftButton Diary
        Button buttonLeftDiary = new TextButton("<", this.skin);
        buttonLeftDiary.addListener(new ClickListener()
        {
            @Override
            public void clicked(InputEvent event, float x, float y) {
                for (int i = 0; i < 9; i++) {
                    if(counter >=2) {
                        counter--;
                    }else counter = 8;
                }
                SwitchDiaryImage();
            }
        });
        rightTable.clear();
        rightTable.add(buttonLeftDiary).left().padLeft(10f);
        rightTable.add(imageName).center().center().pad(10f).size(650, 600);
        rightTable.add(buttonRightDiary).right().padRight(10f);
    }

    /**
     *   The switch function to the showDiaryImage function, so that the correct image is displayed
     */
    private void SwitchDiaryImage() {
        switch(counter) {
            case 1:
                showDiaryImage(diaryImageCover);
                break;
            case 2:
                showDiaryImage(diaryImageOne);
                break;
            case 3:
                showDiaryImage(diaryImageTwo);
                break;
            case 4:
                showDiaryImage(diaryImageThree);
                break;
            case 5:
                showDiaryImage(diaryImageFour);
                break;
            case 6:
                showDiaryImage(diaryImageFive);
                break;
            case 7:
                showDiaryImage(diaryImageSix);
                break;
            case 8:
                showDiaryImage(diaryImageSeven);
        }
    }



    public static String getTime(){
        DateTimeFormatter dtf = DateTimeFormatter.ofPattern("HH:mm:ss");
        return dtf.format(LocalDateTime.now());
    }




    /**
     * Called when the screen should render itself
     *
     * @param delta the time in seconds since the last render.
     */
    @Override
    public void render(float delta) {

        // clear screen
        Gdx.gl.glClearColor(1f, 1f, 1f, 1);
        Gdx.gl.glClear(GL20.GL_COLOR_BUFFER_BIT);


        stage.act();
        spriteBatch.begin();
        backgroundSprite.draw(spriteBatch);
        timeLabel.setText(getTime());
        spriteBatch.end();

        stage.draw();
    }

    /**
     * Called when this screen should release all resources
     */
    @Override
    public void dispose() {
        stage.dispose();

    }
}

