package com.mygdx.game.screens;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.ScreenAdapter;
import com.badlogic.gdx.graphics.GL20;
import com.badlogic.gdx.graphics.Texture;
import com.badlogic.gdx.graphics.g2d.Sprite;
import com.badlogic.gdx.graphics.g2d.SpriteBatch;
import com.badlogic.gdx.scenes.scene2d.InputEvent;
import com.badlogic.gdx.scenes.scene2d.Stage;
import com.badlogic.gdx.scenes.scene2d.ui.Button;
import com.badlogic.gdx.scenes.scene2d.ui.Table;
import com.badlogic.gdx.scenes.scene2d.utils.ClickListener;
import com.badlogic.gdx.utils.viewport.ExtendViewport;
import com.badlogic.gdx.utils.viewport.Viewport;
import com.mygdx.game.Game;
import com.mygdx.game.Music.MusicController;
import com.mygdx.game.ui.UIElementCreator;
import com.mygdx.game.ui.UIStyle;

public class WinScreen extends ScreenAdapter {

    private static Stage stage; // used to display user-Interface
    private static Viewport viewport; // display different resolutions
    private static Table mainTable;

    private static Texture backgroundTexture;
    private static Sprite backgroundSprite;
    private static SpriteBatch spriteBatch = new SpriteBatch();


    @Override
    public void show() {

        createScreen();
        MusicController.startMusic(1f);

        // create and layout UI elements
        createScreen();

        Button exitButton = UIElementCreator.createTextButton("Beenden",UIStyle.Comic);
        exitButton.addListener(new ClickListener()
        {
            /**
             * Will change the screen to the MainMenuScreen
             * @param event button is clicked
             * @param x
             * @param y
             */
            @Override
            public void clicked(InputEvent event, float x, float y) {
                MusicController.playButtonSound();
                Game.getGameInstance().setScreen(new MainMenuScreen());

            }
        });
        exitButton.setVisible(false);

        Button continueButton = UIElementCreator.createTextButton("Weiter", UIStyle.Comic);
        continueButton.addListener(new ClickListener()
        {
            /**
             * Will change the screen to the MainMenuScreen
             * @param event button is clicked
             * @param x
             * @param y
             */
            @Override
            public void clicked(InputEvent event, float x, float y) {
                MusicController.playButtonSound();
                exitButton.setVisible(true);
                backgroundTexture = new Texture(Gdx.files.internal("EndStory/EndStory.jpg"));
                backgroundSprite = new Sprite(backgroundTexture);
                backgroundSprite.setSize(Gdx.graphics.getWidth(), Gdx.graphics.getHeight());
                continueButton.setVisible(false);

            }
        });


        // Layout UI elements
        mainTable.add(exitButton).top().right().pad(10f).expandX().row();
        mainTable.add(continueButton).top().center().expand();

        Gdx.input.setInputProcessor(stage);
    }

    /**
     * Adds TextButtons to the table with the same paddings
     *
     * @param name name of the button that will be displayed in UI
     * @return one TextButton for the menu
     */


    /**
     * Called when the screen should render itself
     *
     * @param delta the time in seconds since the last render.
     */
    @Override
    public void render(float delta) {

        // clear screen
        Gdx.gl.glClearColor(1f, 1f, 1f, 1);
        Gdx.gl.glClear(GL20.GL_COLOR_BUFFER_BIT);

        stage.act();

        spriteBatch.begin();
        backgroundSprite.draw(spriteBatch);
        spriteBatch.end();

        stage.draw();
    }


    @Override
    public void resize(int width, int height) {
        viewport.update(width, height);
    }



    @Override
    public void hide() {
        super.hide();
    }

    @Override
    public void dispose() {
        stage.dispose();

    }

    private static void createScreen() {
        viewport = new ExtendViewport(1280, 720);
        stage = new Stage(viewport);
        mainTable = new Table();
        mainTable.setFillParent(true);
        stage.addActor(mainTable);

        backgroundTexture = new Texture(Gdx.files.internal("WinLoseScreen/WinScreen.jpg"));
        backgroundSprite = new Sprite(backgroundTexture);
        backgroundSprite.setSize(Gdx.graphics.getWidth(), Gdx.graphics.getHeight());
    }

}
