package com.mygdx.game.ui;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.graphics.Color;
import com.badlogic.gdx.graphics.Texture;
import com.badlogic.gdx.graphics.g2d.BitmapFont;
import com.badlogic.gdx.graphics.g2d.TextureAtlas;
import com.badlogic.gdx.graphics.g2d.TextureRegion;
import com.badlogic.gdx.graphics.g2d.freetype.*;
import com.badlogic.gdx.scenes.scene2d.ui.*;
import com.badlogic.gdx.scenes.scene2d.utils.TextureRegionDrawable;
import sun.font.TextLabel;

public class UIElementCreator {

    //private static Skin comicSkin = new Skin(Gdx.files.internal("skinComic/comic-ui.json"));
    private static Skin comicSkin = new Skin();
    private static Skin cloudSkin = new Skin(Gdx.files.internal("skinCloud/cloud-form-ui.json"));
    private static Skin expeeSkin = new Skin(Gdx.files.internal("skinExpee/expee-ui.json"));

    private static boolean isSkinAlreadyInitialized = false;


    public static void initializeSkin()
    {
        if(isSkinAlreadyInitialized == false)
        {
            // initialize comicSpecial Skin
            FreeTypeFontGenerator generator = new FreeTypeFontGenerator(Gdx.files.internal("Roboto-Black.ttf"));
            FreeTypeFontGenerator.FreeTypeFontParameter parameter = new FreeTypeFontGenerator.FreeTypeFontParameter();
            parameter.size = 15;
            parameter.color = Color.BLACK;
            BitmapFont font = generator.generateFont(parameter);
            comicSkin.add("Roboto-Black",font);
            comicSkin.addRegions(new TextureAtlas("skinComicSpecial/skinComicSpecial.atlas"));
            comicSkin.load(Gdx.files.internal("skinComicSpecial/skinComicSpecial.json"));

            isSkinAlreadyInitialized = true;
        }
    }

    public static ImageButton createImageButton(String pictureName)
    {
        initializeSkin();

        Texture texture = new Texture(Gdx.files.internal(pictureName));
        TextureRegion textureRegion = new TextureRegion(texture);
        TextureRegionDrawable textureRegionDrawable = new TextureRegionDrawable(textureRegion);
        ImageButton imageButton = new ImageButton(textureRegionDrawable); //Set the button up

        return imageButton;
    }

    public static ImageButton createImageButton(TextureRegion textureRegion)
    {
        initializeSkin();

        TextureRegionDrawable textureRegionDrawable = new TextureRegionDrawable(textureRegion);
        ImageButton imageButton = new ImageButton(textureRegionDrawable); //Set the button up

        return imageButton;
    }

    public static TextButton createTextButton(String text, UIStyle uIStyle)
    {
        initializeSkin();

        if(uIStyle == UIStyle.Comic)
        {
            return new TextButton(text, comicSkin);
        }
        if(uIStyle == UIStyle.Default)
        {
            // change label so the cloudskin has the same font like the other style
            TextButton textButton = new TextButton("", cloudSkin);
            Label comicLabel = new Label(text,comicSkin);
            textButton.add(comicLabel);
            return textButton;
        }

        return  new TextButton(text, comicSkin);

    }

    public static TextField createTextfield(String inlineText, UIStyle uIStyle)
    {
        initializeSkin();

        if(uIStyle == UIStyle.Comic)
        {
            return new TextField(inlineText, comicSkin);
        }
        return new TextField(inlineText, comicSkin);

    }


    public static SelectBox createSelectBox(String[] entries, UIStyle uiStyle)
    {

        initializeSkin();

        SelectBox<String> selectBox;

       if(uiStyle == UIStyle.Comic){
           selectBox = new SelectBox<String>(comicSkin);
       }
       else
       {
           selectBox = new SelectBox<String>(comicSkin);
       }

        selectBox.setItems(entries);
        return selectBox;
    }

    public static Label createLabel(String title, UIStyle uiStyle)
    {
        initializeSkin();

        if(uiStyle == UIStyle.Title)
        {
            return new Label(title, comicSkin, "title");
        }
        if(uiStyle == UIStyle.SpeechBubble)
        {
            return new Label(title, comicSkin, "bubble");
        }
        if(uiStyle == UIStyle.Narration)
        {
            return new Label(title, comicSkin, "narration");
        }
        if(uiStyle == UIStyle.Window)
        {
            return new Label(title,comicSkin, "alt");
        }

        return new Label(title, comicSkin);
    }

    public static TextArea createTextArea(String text, UIStyle uiStyle)
    {
        initializeSkin();

        if(uiStyle == UIStyle.Dialogue){
            return new TextArea(text,comicSkin,"dialogue");
        }
        if(uiStyle == UIStyle.Alt)
        {
            return new TextArea(text,comicSkin,"alt");
        }
        return new TextArea(text,comicSkin);
    }

    public static Window createWindow(String title, UIStyle uiStyle)
    {
        initializeSkin();

        if(uiStyle == UIStyle.Alt)
        {
            return new Window(title,comicSkin,"alt");
        }
        return new Window(title,comicSkin);
    }


    public static ProgressBar createProgressBar()
    {

        initializeSkin();
        return  new ProgressBar(0f,1.0f,0.01f,false,comicSkin);
    }

    public static Slider createSlider()
    {
        return new Slider(0f,1.0f,0.01f,false,comicSkin);
    }


}
